param($installPath, $toolsPath, $package, $project)
    # MSBuild Targets file to add
    $targetsFile = [System.IO.Path]::Combine($toolsPath, 'Microsoft.TypeScript.targets')
    $propsFile = [System.IO.Path]::Combine($toolsPath, 'Microsoft.TypeScript.Default.props')

    # Load MSBuild assembly
    Add-Type -AssemblyName 'Microsoft.Build, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a'
    $msbuild = [Microsoft.Build.Evaluation.ProjectCollection]::GlobalProjectCollection.GetLoadedProjects($project.FullName) | Select-Object -First 1

    # Make relative paths
    $projectUri = new-object Uri('file://' + $project.FullName)
    $targetsUri = new-object Uri('file://' + $targetsFile)

    # Make relative URI and fix up slashes
    $targetsRelative = $projectUri.MakeRelativeUri($targetsUri).ToString().Replace([System.IO.Path]::AltDirectorySeparatorChar, [System.IO.Path]::DirectorySeparatorChar)
    $propsUri = new-object Uri('file://' + $propsFile)
    $propsRelative = $projectUri.MakeRelativeUri($propsUri).ToString().Replace([System.IO.Path]::AltDirectorySeparatorChar, [System.IO.Path]::DirectorySeparatorChar)

    # Add the targets import at the bottom
    $anchorTarget = $msbuild.Xml.Imports | Where-Object { $_.Project.EndsWith("Microsoft.VisualBasic.targets") -or $_.Project.EndsWith("Microsoft.CSharp.targets") }

    $targetsElement = $msbuild.Xml.CreateImportElement($targetsRelative)
    $targetsElement.Condition = "Exists('" + $targetsRelative + "')"
    $msbuild.Xml.InsertAfterChild($targetsElement,  $anchorTarget) | out-null

    # Add the props import at the top
    $propsElement = $msbuild.Xml.CreateImportElement($propsRelative)
    $propsElement.Condition = "Exists('" + $propsRelative + "')"
    $msbuild.Xml.PrependChild($propsElement) | out-null

    # save project
    $project.Save()
